[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)
[![PyPI badge](http://img.shields.io/pypi/v/sciline.svg)](https://pypi.python.org/pypi/sciline)
[![Anaconda-Server Badge](https://anaconda.org/scipp/sciline/badges/version.svg)](https://anaconda.org/scipp/sciline)
[![License: BSD 3-Clause](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](LICENSE)

![logo](docs/_static/logo.svg)

# Sciline

## About

Build scientific pipelines for your data.
Sciline uses a dependency-injection mechanism to build task graphs that can be executed, e.g., with a Dask scheduler.

See the [documentation](https://scipp.github.io/sciline/) for details.

## Installation

```sh
python -m pip install sciline
```
